==> kubernetes-model-core-5.11.0-sources.jar: io/fabric8/kubernetes/api/model/RBDPersistentVolumeSourceFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class RBDPersistentVolumeSourceFluentImpl<A extends io.fabric8.kubernetes.api.model.RBDPersistentVolumeSourceFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.RBDPersistentVolumeSourceFluent<A>{
  public RBDPersistentVolumeSourceFluentImpl() {
  }
  public RBDPersistentVolumeSourceFluentImpl(io.fabric8.kubernetes.api.model.RBDPersistentVolumeSource instance) {
    this.withFsType(instance.getFsType()); 
    this.withImage(instance.getImage()); 
    this.withKeyring(instance.getKeyring()); 
    this.withMonitors(instance.getMonitors()); 
    this.withPool(instance.getPool()); 
    this.withReadOnly(instance.getReadOnly()); 
    this.withSecretRef(instance.getSecretRef()); 
    this.withUser(instance.getUser()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String fsType;
  private java.lang.String image;
  private java.lang.String keyring;
  private java.util.List<java.lang.String> monitors = new java.util.ArrayList<java.lang.String>();
  private java.lang.String pool;
  private java.lang.Boolean readOnly;
  private io.fabric8.kubernetes.api.model.SecretReferenceBuilder secretRef;
  private java.lang.String user;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getFsType() {
    return this.fsType;
  }
  public A withFsType(java.lang.String fsType) {
    this.fsType=fsType; return (A) this;
  }
  public java.lang.Boolean hasFsType() {
    return this.fsType != null;
  }
  
  /**
   * Method is deprecated. use withFsType instead.
   */
  @java.lang.Deprecated
  public A withNewFsType(java.lang.String arg0) {
    return (A)withFsType(new String(arg0));
  }
  public java.lang.String getImage() {
    return this.image;
  }
  public A withImage(java.lang.String image) {
    this.image=image; return (A) this;
  }
  public java.lang.Boolean hasImage() {
    return this.image != null;
  }
  
  /**
   * Method is deprecated. use withImage instead.
   */
  @java.lang.Deprecated
  public A withNewImage(java.lang.String arg0) {
    return (A)withImage(new String(arg0));
  }
  public java.lang.String getKeyring() {
    return this.keyring;
  }
  public A withKeyring(java.lang.String keyring) {
    this.keyring=keyring; return (A) this;
  }
  public java.lang.Boolean hasKeyring() {
    return this.keyring != null;
  }
  
  /**
   * Method is deprecated. use withKeyring instead.
   */
  @java.lang.Deprecated
  public A withNewKeyring(java.lang.String arg0) {
    return (A)withKeyring(new String(arg0));
  }
  public A addToMonitors(java.lang.Integer index,java.lang.String item) {
    if (this.monitors == null) {this.monitors = new java.util.ArrayList<java.lang.String>();}
    this.monitors.add(index, item);
    return (A)this;
  }
  public A setToMonitors(java.lang.Integer index,java.lang.String item) {
    if (this.monitors == null) {this.monitors = new java.util.ArrayList<java.lang.String>();}
    this.monitors.set(index, item); return (A)this;
  }
  public A addToMonitors(java.lang.String... items) {
    if (this.monitors == null) {this.monitors = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.monitors.add(item);} return (A)this;
  }
  public A addAllToMonitors(java.util.Collection<java.lang.String> items) {
    if (this.monitors == null) {this.monitors = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.monitors.add(item);} return (A)this;
  }
  public A removeFromMonitors(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.monitors!= null){ this.monitors.remove(item);}} return (A)this;
  }
  public A removeAllFromMonitors(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.monitors!= null){ this.monitors.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getMonitors() {
    return this.monitors;
  }
  public java.lang.String getMonitor(java.lang.Integer index) {
    return this.monitors.get(index);
  }
  public java.lang.String getFirstMonitor() {
    return this.monitors.get(0);
  }
  public java.lang.String getLastMonitor() {
    return this.monitors.get(monitors.size() - 1);
  }
  public java.lang.String getMatchingMonitor(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: monitors) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingMonitor(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: monitors) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withMonitors(java.util.List<java.lang.String> monitors) {
    if (monitors != null) {this.monitors = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : monitors){this.addToMonitors(item);}} else { this.monitors = null;} return (A) this;
  }
  public A withMonitors(java.lang.String... monitors) {
    if (this.monitors != null) {this.monitors.clear();}
    if (monitors != null) {for (java.lang.String item :monitors){ this.addToMonitors(item);}} return (A) this;
  }
  public java.lang.Boolean hasMonitors() {
    return monitors != null && !monitors.isEmpty();
  }
  public A addNewMonitor(java.lang.String arg0) {
    return (A)addToMonitors(new String(arg0));
  }
  public java.lang.String getPool() {
    return this.pool;
  }
  public A withPool(java.lang.String pool) {
    this.pool=pool; return (A) this;
  }
  public java.lang.Boolean hasPool() {
    return this.pool != null;
  }
  
  /**
   * Method is deprecated. use withPool instead.
   */
  @java.lang.Deprecated
  public A withNewPool(java.lang.String arg0) {
    return (A)withPool(new String(arg0));
  }
  public java.lang.Boolean getReadOnly() {
    return this.readOnly;
  }
  public A withReadOnly(java.lang.Boolean readOnly) {
    this.readOnly=readOnly; return (A) this;
  }
  public java.lang.Boolean hasReadOnly() {
    return this.readOnly != null;
  }
  
  /**
   * This method has been deprecated, please use method buildSecretRef instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.SecretReference getSecretRef() {
    return this.secretRef!=null?this.secretRef.build():null;
  }
  public io.fabric8.kubernetes.api.model.SecretReference buildSecretRef() {
    return this.secretRef!=null?this.secretRef.build():null;
  }
  public A withSecretRef(io.fabric8.kubernetes.api.model.SecretReference secretRef) {
    _visitables.get("secretRef").remove(this.secretRef);
    if (secretRef!=null){ this.secretRef= new io.fabric8.kubernetes.api.model.SecretReferenceBuilder(secretRef); _visitables.get("secretRef").add(this.secretRef);} return (A) this;
  }
  public java.lang.Boolean hasSecretRef() {
    return this.secretRef != null;
  }
  public A withNewSecretRef(java.lang.String name,java.lang.String namespace) {
    return (A)withSecretRef(new SecretReference(name, namespace));
  }
  public io.fabric8.kubernetes.api.model.RBDPersistentVolumeSourceFluent.SecretRefNested<A> withNewSecretRef() {
    return new io.fabric8.kubernetes.api.model.RBDPersistentVolumeSourceFluentImpl.SecretRefNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.RBDPersistentVolumeSourceFluent.SecretRefNested<A> withNewSecretRefLike(io.fabric8.kubernetes.api.model.SecretReference item) {
    return new io.fabric8.kubernetes.api.model.RBDPersistentVolumeSourceFluentImpl.SecretRefNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.RBDPersistentVolumeSourceFluent.SecretRefNested<A> editSecretRef() {
    return withNewSecretRefLike(getSecretRef());
  }
  public io.fabric8.kubernetes.api.model.RBDPersistentVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRef() {
    return withNewSecretRefLike(getSecretRef() != null ? getSecretRef(): new io.fabric8.kubernetes.api.model.SecretReferenceBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.RBDPersistentVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRefLike(io.fabric8.kubernetes.api.model.SecretReference item) {
    return withNewSecretRefLike(getSecretRef() != null ? getSecretRef(): item);
  }
  public java.lang.String getUser() {
    return this.user;
  }
  public A withUser(java.lang.String user) {
    this.user=user; return (A) this;
  }
  public java.lang.Boolean hasUser() {
    return this.user != null;
  }
  
  /**
   * Method is deprecated. use withUser instead.
   */
  @java.lang.Deprecated
  public A withNewUser(java.lang.String arg0) {
    return (A)withUser(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    RBDPersistentVolumeSourceFluentImpl that = (RBDPersistentVolumeSourceFluentImpl) o;
    if (fsType != null ? !fsType.equals(that.fsType) :that.fsType != null) return false;
    if (image != null ? !image.equals(that.image) :that.image != null) return false;
    if (keyring != null ? !keyring.equals(that.keyring) :that.keyring != null) return false;
    if (monitors != null ? !monitors.equals(that.monitors) :that.monitors != null) return false;
    if (pool != null ? !pool.equals(that.pool) :that.pool != null) return false;
    if (readOnly != null ? !readOnly.equals(that.readOnly) :that.readOnly != null) return false;
    if (secretRef != null ? !secretRef.equals(that.secretRef) :that.secretRef != null) return false;
    if (user != null ? !user.equals(that.user) :that.user != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fsType,  image,  keyring,  monitors,  pool,  readOnly,  secretRef,  user,  additionalProperties,  super.hashCode());
  }
  public class SecretRefNestedImpl<N> extends io.fabric8.kubernetes.api.model.SecretReferenceFluentImpl<io.fabric8.kubernetes.api.model.RBDPersistentVolumeSourceFluent.SecretRefNested<N>> implements io.fabric8.kubernetes.api.model.RBDPersistentVolumeSourceFluent.SecretRefNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    SecretRefNestedImpl(io.fabric8.kubernetes.api.model.SecretReference item) {
      this.builder = new io.fabric8.kubernetes.api.model.SecretReferenceBuilder(this, item);
    }
    SecretRefNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.SecretReferenceBuilder(this);
    }
    io.fabric8.kubernetes.api.model.SecretReferenceBuilder builder;
    public N and() {
      return (N) RBDPersistentVolumeSourceFluentImpl.this.withSecretRef(builder.build());
    }
    public N endSecretRef() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-core-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/RBDPersistentVolumeSourceFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class RBDPersistentVolumeSourceFluentImpl<A extends io.fabric8.kubernetes.api.model.RBDPersistentVolumeSourceFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.RBDPersistentVolumeSourceFluent<A>{
  public RBDPersistentVolumeSourceFluentImpl() {
  }
  public RBDPersistentVolumeSourceFluentImpl(io.fabric8.kubernetes.api.model.RBDPersistentVolumeSource instance) {
    this.withFsType(instance.getFsType()); 
    this.withImage(instance.getImage()); 
    this.withKeyring(instance.getKeyring()); 
    this.withMonitors(instance.getMonitors()); 
    this.withPool(instance.getPool()); 
    this.withReadOnly(instance.getReadOnly()); 
    this.withSecretRef(instance.getSecretRef()); 
    this.withUser(instance.getUser()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String fsType;
  private java.lang.String image;
  private java.lang.String keyring;
  private java.util.List<java.lang.String> monitors = new java.util.ArrayList<java.lang.String>();
  private java.lang.String pool;
  private java.lang.Boolean readOnly;
  private io.fabric8.kubernetes.api.model.SecretReferenceBuilder secretRef;
  private java.lang.String user;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getFsType() {
    return this.fsType;
  }
  public A withFsType(java.lang.String fsType) {
    this.fsType=fsType; return (A) this;
  }
  public java.lang.Boolean hasFsType() {
    return this.fsType != null;
  }
  
  /**
   * Method is deprecated. use withFsType instead.
   */
  @java.lang.Deprecated
  public A withNewFsType(java.lang.String arg0) {
    return (A)withFsType(new String(arg0));
  }
  public java.lang.String getImage() {
    return this.image;
  }
  public A withImage(java.lang.String image) {
    this.image=image; return (A) this;
  }
  public java.lang.Boolean hasImage() {
    return this.image != null;
  }
  
  /**
   * Method is deprecated. use withImage instead.
   */
  @java.lang.Deprecated
  public A withNewImage(java.lang.String arg0) {
    return (A)withImage(new String(arg0));
  }
  public java.lang.String getKeyring() {
    return this.keyring;
  }
  public A withKeyring(java.lang.String keyring) {
    this.keyring=keyring; return (A) this;
  }
  public java.lang.Boolean hasKeyring() {
    return this.keyring != null;
  }
  
  /**
   * Method is deprecated. use withKeyring instead.
   */
  @java.lang.Deprecated
  public A withNewKeyring(java.lang.String arg0) {
    return (A)withKeyring(new String(arg0));
  }
  public A addToMonitors(java.lang.Integer index,java.lang.String item) {
    if (this.monitors == null) {this.monitors = new java.util.ArrayList<java.lang.String>();}
    this.monitors.add(index, item);
    return (A)this;
  }
  public A setToMonitors(java.lang.Integer index,java.lang.String item) {
    if (this.monitors == null) {this.monitors = new java.util.ArrayList<java.lang.String>();}
    this.monitors.set(index, item); return (A)this;
  }
  public A addToMonitors(java.lang.String... items) {
    if (this.monitors == null) {this.monitors = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.monitors.add(item);} return (A)this;
  }
  public A addAllToMonitors(java.util.Collection<java.lang.String> items) {
    if (this.monitors == null) {this.monitors = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.monitors.add(item);} return (A)this;
  }
  public A removeFromMonitors(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.monitors!= null){ this.monitors.remove(item);}} return (A)this;
  }
  public A removeAllFromMonitors(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.monitors!= null){ this.monitors.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getMonitors() {
    return this.monitors;
  }
  public java.lang.String getMonitor(java.lang.Integer index) {
    return this.monitors.get(index);
  }
  public java.lang.String getFirstMonitor() {
    return this.monitors.get(0);
  }
  public java.lang.String getLastMonitor() {
    return this.monitors.get(monitors.size() - 1);
  }
  public java.lang.String getMatchingMonitor(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: monitors) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingMonitor(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: monitors) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withMonitors(java.util.List<java.lang.String> monitors) {
    if (monitors != null) {this.monitors = new java.util.ArrayList(); for (java.lang.String item : monitors){this.addToMonitors(item);}} else { this.monitors = null;} return (A) this;
  }
  public A withMonitors(java.lang.String... monitors) {
    if (this.monitors != null) {this.monitors.clear();}
    if (monitors != null) {for (java.lang.String item :monitors){ this.addToMonitors(item);}} return (A) this;
  }
  public java.lang.Boolean hasMonitors() {
    return monitors != null && !monitors.isEmpty();
  }
  public A addNewMonitor(java.lang.String arg0) {
    return (A)addToMonitors(new String(arg0));
  }
  public java.lang.String getPool() {
    return this.pool;
  }
  public A withPool(java.lang.String pool) {
    this.pool=pool; return (A) this;
  }
  public java.lang.Boolean hasPool() {
    return this.pool != null;
  }
  
  /**
   * Method is deprecated. use withPool instead.
   */
  @java.lang.Deprecated
  public A withNewPool(java.lang.String arg0) {
    return (A)withPool(new String(arg0));
  }
  public java.lang.Boolean getReadOnly() {
    return this.readOnly;
  }
  public A withReadOnly(java.lang.Boolean readOnly) {
    this.readOnly=readOnly; return (A) this;
  }
  public java.lang.Boolean hasReadOnly() {
    return this.readOnly != null;
  }
  
  /**
   * This method has been deprecated, please use method buildSecretRef instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.SecretReference getSecretRef() {
    return this.secretRef!=null?this.secretRef.build():null;
  }
  public io.fabric8.kubernetes.api.model.SecretReference buildSecretRef() {
    return this.secretRef!=null?this.secretRef.build():null;
  }
  public A withSecretRef(io.fabric8.kubernetes.api.model.SecretReference secretRef) {
    _visitables.get("secretRef").remove(this.secretRef);
    if (secretRef!=null){ this.secretRef= new io.fabric8.kubernetes.api.model.SecretReferenceBuilder(secretRef); _visitables.get("secretRef").add(this.secretRef);} return (A) this;
  }
  public java.lang.Boolean hasSecretRef() {
    return this.secretRef != null;
  }
  public A withNewSecretRef(java.lang.String name,java.lang.String namespace) {
    return (A)withSecretRef(new SecretReference(name, namespace));
  }
  public io.fabric8.kubernetes.api.model.RBDPersistentVolumeSourceFluent.SecretRefNested<A> withNewSecretRef() {
    return new io.fabric8.kubernetes.api.model.RBDPersistentVolumeSourceFluentImpl.SecretRefNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.RBDPersistentVolumeSourceFluent.SecretRefNested<A> withNewSecretRefLike(io.fabric8.kubernetes.api.model.SecretReference item) {
    return new io.fabric8.kubernetes.api.model.RBDPersistentVolumeSourceFluentImpl.SecretRefNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.RBDPersistentVolumeSourceFluent.SecretRefNested<A> editSecretRef() {
    return withNewSecretRefLike(getSecretRef());
  }
  public io.fabric8.kubernetes.api.model.RBDPersistentVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRef() {
    return withNewSecretRefLike(getSecretRef() != null ? getSecretRef(): new io.fabric8.kubernetes.api.model.SecretReferenceBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.RBDPersistentVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRefLike(io.fabric8.kubernetes.api.model.SecretReference item) {
    return withNewSecretRefLike(getSecretRef() != null ? getSecretRef(): item);
  }
  public java.lang.String getUser() {
    return this.user;
  }
  public A withUser(java.lang.String user) {
    this.user=user; return (A) this;
  }
  public java.lang.Boolean hasUser() {
    return this.user != null;
  }
  
  /**
   * Method is deprecated. use withUser instead.
   */
  @java.lang.Deprecated
  public A withNewUser(java.lang.String arg0) {
    return (A)withUser(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    RBDPersistentVolumeSourceFluentImpl that = (RBDPersistentVolumeSourceFluentImpl) o;
    if (fsType != null ? !fsType.equals(that.fsType) :that.fsType != null) return false;
    if (image != null ? !image.equals(that.image) :that.image != null) return false;
    if (keyring != null ? !keyring.equals(that.keyring) :that.keyring != null) return false;
    if (monitors != null ? !monitors.equals(that.monitors) :that.monitors != null) return false;
    if (pool != null ? !pool.equals(that.pool) :that.pool != null) return false;
    if (readOnly != null ? !readOnly.equals(that.readOnly) :that.readOnly != null) return false;
    if (secretRef != null ? !secretRef.equals(that.secretRef) :that.secretRef != null) return false;
    if (user != null ? !user.equals(that.user) :that.user != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fsType,  image,  keyring,  monitors,  pool,  readOnly,  secretRef,  user,  additionalProperties,  super.hashCode());
  }
  public class SecretRefNestedImpl<N> extends io.fabric8.kubernetes.api.model.SecretReferenceFluentImpl<io.fabric8.kubernetes.api.model.RBDPersistentVolumeSourceFluent.SecretRefNested<N>> implements io.fabric8.kubernetes.api.model.RBDPersistentVolumeSourceFluent.SecretRefNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    SecretRefNestedImpl(io.fabric8.kubernetes.api.model.SecretReference item) {
      this.builder = new io.fabric8.kubernetes.api.model.SecretReferenceBuilder(this, item);
    }
    SecretRefNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.SecretReferenceBuilder(this);
    }
    io.fabric8.kubernetes.api.model.SecretReferenceBuilder builder;
    public N and() {
      return (N) RBDPersistentVolumeSourceFluentImpl.this.withSecretRef(builder.build());
    }
    public N endSecretRef() {
      return and();
    }
    
  }
  
}
